@@ -1,12 +1,12 @@
 package Alien::Libgpg_error;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 use 5.006;
 use strict;
 use warnings;
 
-use parent qw(Alien::Base);
+use base qw(Alien::Base);
 
 1;
 
